import { RefObject } from 'react';
import { TrackingResult } from '../../components/Tracking';
type EventHandler<NativeEventType extends MouseEvent> = (result: TrackingResult<NativeEventType>) => void;
type PointerEventName = 'onPointerEnter' | 'onPointerDown' | 'onPointerMove' | 'onPointerUp' | 'onPointerLeave';
type ClickEventName = 'onClick' | 'onDoubleClick';
type WheelEventName = 'onWheel';
export type EventName = PointerEventName | ClickEventName | WheelEventName;
type PointerEventHandlers = {
    [key in PointerEventName]?: EventHandler<PointerEvent>;
};
type ClickEventHandlers = {
    [key in ClickEventName]?: EventHandler<MouseEvent>;
};
type WheelEventHandlers = {
    [key in WheelEventName]?: EventHandler<WheelEvent>;
};
export type EventsHandlers = PointerEventHandlers & ClickEventHandlers & WheelEventHandlers;
type EventMap = {
    [key in PointerEventName]: PointerEvent;
} & {
    [key in ClickEventName]: MouseEvent;
} & {
    [key in WheelEventName]: WheelEvent;
};
export interface PlotEventsUserActions {
    registerHandlers: (handlersRef: RefObject<EventsHandlers>) => void;
    unregisterHandlers: (handlersRef: RefObject<EventsHandlers>) => void;
}
export interface PlotEventsPlotActions {
    registerPlot: (plotId: string) => void;
    unregisterPlot: (plotId: string) => void;
    handleEvent: <T extends EventName>(plotId: string, eventName: T, eventData: TrackingResult<EventMap[T]>) => void;
}
export declare function usePlotEventsState(): {
    userActions: PlotEventsUserActions;
    plotActions: PlotEventsPlotActions;
};
export {};
//# sourceMappingURL=usePlotEvents.d.ts.map