"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Axis = Axis;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const plotContext_1 = require("../../contexts/plotContext");
const axis_1 = require("../../utils/axis");
const LinearAxis_1 = __importDefault(require("./LinearAxis"));
const LogAxis_1 = __importDefault(require("./LogAxis"));
const TimeAxis_1 = __importDefault(require("./TimeAxis"));
function Axis({ id, position, min, max, paddingStart = 0, paddingEnd = 0, flip = false, scale = 'linear', 
// children props
label, displayPrimaryGridLines = false, primaryGridLineStyle, displaySecondaryGridLines, secondaryGridLineStyle, labelStyle, hidden = false, tickLabelStyle, tickLabelFormat = scale === 'time' ? undefined : String, hiddenLine = false, lineStyle, hiddenTicks = false, tickPosition = 'outer', primaryTickLength = 5, primaryTickStyle, secondaryTickLength = 3, secondaryTickStyle, }) {
    const dispatch = (0, plotContext_1.usePlotDispatchContext)();
    const { axisContext, plotWidth, plotHeight } = (0, plotContext_1.usePlotContext)();
    const xY = ['top', 'bottom'].includes(position) ? 'x' : 'y';
    const axisId = id || xY;
    const innerOffset = (0, axis_1.getInnerOffset)(hidden, hiddenTicks, tickPosition, primaryTickLength);
    (0, react_1.useEffect)(() => {
        dispatch({
            type: 'addAxis',
            payload: {
                id: axisId,
                position,
                min,
                max,
                paddingStart,
                paddingEnd,
                flip,
                scale,
                innerOffset,
                tickLabelFormat,
            },
        });
        return () => dispatch({ type: 'removeAxis', payload: { id: axisId } });
    }, [
        dispatch,
        flip,
        innerOffset,
        max,
        min,
        paddingEnd,
        paddingStart,
        position,
        scale,
        axisId,
        tickLabelFormat,
    ]);
    const currentAxis = axisContext[axisId];
    if (!currentAxis)
        return null;
    const childProps = {
        hidden,
        plotWidth,
        plotHeight,
        displayPrimaryGridLines,
        label,
        labelStyle,
        tickLabelStyle,
        position,
        hiddenLine,
        primaryGridLineStyle,
        displaySecondaryGridLines,
        secondaryGridLineStyle,
        lineStyle,
        hiddenTicks,
        tickPosition,
        primaryTickLength,
        primaryTickStyle,
        innerOffset,
        secondaryTickLength,
        secondaryTickStyle,
    };
    if (scale === 'linear') {
        return ((0, jsx_runtime_1.jsx)(LinearAxis_1.default, { ...childProps, tickLabelFormat: tickLabelFormat, scale: currentAxis.scale }));
    }
    else if (scale === 'time') {
        return ((0, jsx_runtime_1.jsx)(TimeAxis_1.default, { ...childProps, tickLabelFormat: tickLabelFormat, scale: currentAxis.scale }));
    }
    else {
        return ((0, jsx_runtime_1.jsx)(LogAxis_1.default, { ...childProps, tickLabelFormat: tickLabelFormat, scale: currentAxis.scale }));
    }
}
//# sourceMappingURL=Axis.js.map