"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = HorizontalAxis;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_d3_utils_1 = require("react-d3-utils");
const bboxContext_1 = require("../../contexts/bboxContext");
const HorizontalAxisGridLines_1 = __importDefault(require("./HorizontalAxisGridLines"));
const HorizontalAxisLabel_1 = __importDefault(require("./HorizontalAxisLabel"));
const HorizontalAxisLine_1 = __importDefault(require("./HorizontalAxisLine"));
const Ticks_1 = require("./Ticks");
function HorizontalAxis(props) {
    const { primaryTickStyle, primaryTickLength, tickPosition, hiddenTicks, lineStyle, hiddenLine, hidden, plotWidth, plotHeight, displayPrimaryGridLines, displaySecondaryGridLines, primaryGridLineStyle, secondaryGridLineStyle, label, labelStyle, axisRef, primaryTicks, position, tickLabelStyle, innerOffset, secondaryTickLength, scale, secondaryTickStyle, } = props;
    const isBottom = position === 'bottom';
    const textOffset = 0;
    const transform = isBottom ? `translate(0, ${plotHeight})` : undefined;
    const ticks = (0, react_d3_utils_1.useBBoxObserver)();
    function getTickPosition(value, secondary = false) {
        const { y1, y2, textPosition } = getTickY(secondary);
        return {
            line: {
                x1: value,
                x2: value,
                y1,
                y2,
            },
            text: {
                x1: value,
                y1: isBottom ? textPosition : -textPosition,
            },
        };
    }
    function getTickY(secondary = false) {
        const tickLength = secondary ? secondaryTickLength : primaryTickLength;
        const y = isBottom ? tickLength : -tickLength;
        switch (tickPosition) {
            case 'center':
                return {
                    y1: y / 2,
                    y2: -y / 2,
                    textPosition: textOffset + tickLength / 2,
                };
            case 'inner':
                return {
                    y1: 0,
                    y2: -y,
                    textPosition: textOffset,
                };
            case 'outer':
                return {
                    y1: 0,
                    y2: y,
                    textPosition: textOffset + tickLength,
                };
            default:
                return {
                    y1: 0,
                    y: 0,
                    textPosition: 0,
                };
        }
    }
    const gridLinesElement = displayPrimaryGridLines || displaySecondaryGridLines ? ((0, jsx_runtime_1.jsx)(HorizontalAxisGridLines_1.default, { position: position, plotHeight: plotHeight, primaryTicks: primaryTicks, style: primaryGridLineStyle, primaryGrid: displayPrimaryGridLines, secondaryGrid: displaySecondaryGridLines, secondaryStyle: secondaryGridLineStyle, scale: scale })) : null;
    const primaryTicksElement = !hidden && !hiddenTicks ? ((0, jsx_runtime_1.jsx)(Ticks_1.Ticks, { anchor: "middle", primaryTicks: primaryTicks, getPositions: getTickPosition, labelStyle: tickLabelStyle, style: primaryTickStyle, secondaryTickLength: secondaryTickLength, scale: scale, secondaryTickStyle: secondaryTickStyle, dominantBaseline: isBottom ? 'text-before-edge' : 'text-after-edge' })) : null;
    const axisLineElement = !hidden && !hiddenLine ? ((0, jsx_runtime_1.jsx)(HorizontalAxisLine_1.default, { style: lineStyle, plotWidth: plotWidth })) : null;
    const labelElement = !hidden && label ? ((0, jsx_runtime_1.jsx)(HorizontalAxisLabel_1.default, { plotWidth: plotWidth, label: label, labelStyle: labelStyle, verticalAlign: isBottom ? 'start' : 'end' })) : null;
    const bboxRef = (0, react_1.useContext)(bboxContext_1.bboxContext);
    return ((0, jsx_runtime_1.jsxs)("g", { transform: transform, children: [gridLinesElement, (0, jsx_runtime_1.jsxs)("g", { ref: bboxRef, children: [(0, jsx_runtime_1.jsx)("g", { ref: ticks.ref, children: primaryTicksElement }), (0, jsx_runtime_1.jsx)("g", { ref: axisRef, children: axisLineElement }), (0, jsx_runtime_1.jsx)("g", { transform: `translate(0, ${(ticks.height - innerOffset) * (isBottom ? 1 : -1)})`, children: labelElement })] })] }));
}
//# sourceMappingURL=HorizontalAxis.js.map