"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlotObject = PlotObject;
const jsx_runtime_1 = require("react/jsx-runtime");
const Annotation_1 = require("./Annotations/Annotation");
const Axis_1 = require("./Axis/Axis");
const ParallelAxis_1 = require("./Axis/ParallelAxis");
const Legend_1 = require("./Legend");
const Plot_1 = require("./Plot");
const LineSeries_1 = require("./Series/LineSeries");
const ScatterSeries_1 = require("./Series/ScatterSeries");
function PlotObject({ plot: { dimensions, svg = {}, seriesViewportStyle, axes, content, legend, colorScheme, }, children, }) {
    const { className: svgClassName, id: svgId, style: svgStyle, ...svgProps } = svg;
    return ((0, jsx_runtime_1.jsxs)(Plot_1.Plot, { colorScheme: colorScheme, seriesViewportStyle: seriesViewportStyle, ...dimensions, svgClassName: svgClassName, svgId: svgId, svgStyle: svgStyle, ...svgProps, children: [axes.map((axisProps) => {
                switch (axisProps.type) {
                    case 'main': {
                        const { type, ...props } = axisProps;
                        return (0, jsx_runtime_1.jsx)(Axis_1.Axis, { ...props }, axisProps.position);
                    }
                    case 'secondary': {
                        const { type, ...props } = axisProps;
                        return (0, jsx_runtime_1.jsx)(ParallelAxis_1.ParallelAxis, { ...props }, `secondary-${props.id}`);
                    }
                    default: {
                        return null;
                    }
                }
            }), legend !== undefined ? (0, jsx_runtime_1.jsx)(Legend_1.Legend, { ...legend }) : null, content.map((contentProps, i) => {
                switch (contentProps.type) {
                    case 'line': {
                        const { type, ...props } = contentProps;
                        return (0, jsx_runtime_1.jsx)(LineSeries_1.LineSeries, { ...props }, `${type}-${i}`);
                    }
                    case 'scatter': {
                        const { type, ...props } = contentProps;
                        return (0, jsx_runtime_1.jsx)(ScatterSeries_1.ScatterSeries, { ...props }, `${type}-${i}`);
                    }
                    case 'annotation': {
                        return ((0, jsx_runtime_1.jsx)(Annotation_1.Annotations, { children: contentProps.children.map(annotationMap) }, `${contentProps.type}-${i}`));
                    }
                    default: {
                        return null;
                    }
                }
            }), children && (0, jsx_runtime_1.jsx)(Annotation_1.Annotations, { children: children })] }));
}
function annotationMap(annotationProps, index) {
    switch (annotationProps.type) {
        case 'arrow': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Arrow, { ...props }, `${type}-${index}`);
        }
        case 'circle': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Circle, { ...props }, `${type}-${index}`);
        }
        case 'ellipse': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Ellipse, { ...props }, `${type}-${index}`);
        }
        case 'line': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Line, { ...props }, `${type}-${index}`);
        }
        case 'rectangle': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Rectangle, { ...props }, `${type}-${index}`);
        }
        case 'shape': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Shape, { ...props }, `${type}-${index}`);
        }
        case 'text': {
            const { type, ...props } = annotationProps;
            return (0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Text, { ...props }, `${type}-${index}`);
        }
        case 'group': {
            const { type, children, ...props } = annotationProps;
            return ((0, jsx_runtime_1.jsx)(Annotation_1.Annotation.Group, { ...props, children: children.map(annotationMap) }, `${type}-${index}`));
        }
        default: {
            return null;
        }
    }
}
//# sourceMappingURL=PlotObject.js.map