"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LineSeries = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_shape_1 = require("d3-shape");
const react_1 = require("react");
const legendContext_1 = require("../../contexts/legendContext");
const plotContext_1 = require("../../contexts/plotContext");
const hooks_1 = require("../../hooks");
const utils_1 = require("../../utils");
const ScatterSeries_1 = require("./ScatterSeries");
function LineSeriesInner(props) {
    const [, legendDispatch] = (0, legendContext_1.useLegend)();
    const { colorScaler } = (0, plotContext_1.usePlotContext)();
    const id = (0, utils_1.useId)(props.id, 'series');
    const { lineStyle: lineStyleFromProps = {}, displayMarkers = false, hidden, ...otherProps } = props;
    const { xAxis = 'x', yAxis = 'y', xShift: oldXShift = '0', yShift: oldYShift = '0', pointLabel, displayErrorBars, label, markerStyle, markerShape, } = otherProps;
    const { xShift, yShift } = (0, hooks_1.useShift)({
        xAxis,
        yAxis,
        xShift: oldXShift,
        yShift: oldYShift,
    });
    const lineStyle = (0, utils_1.functionalStyle)({}, lineStyleFromProps, { id });
    const isVisible = (0, hooks_1.useIsSeriesVisible)(id);
    (0, react_1.useEffect)(() => {
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label,
                    colorLine: lineStyle?.stroke?.toString() || colorScaler(id),
                    shape: {
                        color: markerStyle?.fill?.toString() || colorScaler(id),
                        figure: markerShape || 'circle',
                        hidden: !displayMarkers,
                    },
                },
            });
            return () => legendDispatch({ type: 'REMOVE_LEGEND_LABEL', payload: { id } });
        }
    }, [
        hidden,
        colorScaler,
        displayMarkers,
        id,
        legendDispatch,
        lineStyle?.stroke,
        label,
        markerShape,
        markerStyle?.fill,
    ]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data: props.data,
        xAxis,
        yAxis,
        lineStyle,
        transform: `translate(${xShift},${yShift})`,
    };
    return ((0, jsx_runtime_1.jsxs)("g", { children: [isVisible && (0, jsx_runtime_1.jsx)(LineSeriesRender, { ...lineProps }), (0, jsx_runtime_1.jsx)(ScatterSeries_1.ScatterSeries, { ...otherProps, hidden: !displayMarkers && !pointLabel && !displayErrorBars, displayMarkers: displayMarkers, id: id })] }));
}
exports.LineSeries = (0, react_1.memo)(LineSeriesInner);
function LineSeriesRender({ id, data, xAxis, yAxis, lineStyle, transform, }) {
    // Get scales from context
    const { axisContext, colorScaler } = (0, plotContext_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    // calculates the path to display
    const color = colorScaler(id);
    const path = (0, react_1.useMemo)(() => {
        if (xScale === undefined || yScale === undefined) {
            return null;
        }
        // Calculate line from D3
        const lineGenerator = (0, d3_shape_1.line)()
            .x((d) => xScale(d.x))
            .y((d) => yScale(d.y));
        return lineGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        stroke: color,
        strokeWidth: 2,
        ...lineStyle,
    };
    return (0, jsx_runtime_1.jsx)("path", { transform: transform, style: style, d: path, fill: "none" });
}
//# sourceMappingURL=LineSeries.js.map