"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RangeSeries = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const d3_array_1 = require("d3-array");
const d3_shape_1 = require("d3-shape");
const react_1 = require("react");
const legendContext_1 = require("../../contexts/legendContext");
const plotContext_1 = require("../../contexts/plotContext");
const hooks_1 = require("../../hooks");
const utils_1 = require("../../utils");
function RangeSeriesInner(props) {
    const id = (0, utils_1.useId)(props.id, 'series');
    const [, legendDispatch] = (0, legendContext_1.useLegend)();
    const { colorScaler } = (0, plotContext_1.usePlotContext)();
    const { lineStyle = { fill: colorScaler(id), fillOpacity: 0.5 }, hidden, xAxis = 'x', yAxis = 'y', data, label, xShift: propsXShift = '0', yShift: propsYShift = '0', } = props;
    const { xShift, yShift } = (0, hooks_1.useShift)({
        xAxis,
        yAxis,
        xShift: propsXShift,
        yShift: propsYShift,
    });
    // Update plot context with data description
    const dispatch = (0, plotContext_1.usePlotDispatchContext)();
    (0, react_1.useEffect)(() => {
        const [xMin, xMax] = (0, d3_array_1.extent)(data, (d) => d.x);
        const [y1Min, y1Max] = (0, d3_array_1.extent)(data, (d) => d.y1);
        const [y2Min, y2Max] = (0, d3_array_1.extent)(data, (d) => d.y2);
        const x = { min: xMin, max: xMax, shift: propsXShift, axisId: xAxis };
        const y = {
            min: Math.min(y1Min, y2Min),
            max: Math.max(y1Max, y2Max),
            shift: propsYShift,
            axisId: yAxis,
        };
        dispatch({ type: 'addSeries', payload: { id, x, y, label } });
        // Delete information on unmount
        return () => dispatch({ type: 'removeSeries', payload: { id } });
    }, [dispatch, id, data, xAxis, yAxis, label, propsXShift, propsYShift]);
    const isVisible = (0, hooks_1.useIsSeriesVisible)(id);
    (0, react_1.useEffect)(() => {
        if (!hidden) {
            legendDispatch({
                type: 'ADD_LEGEND_LABEL',
                payload: {
                    id,
                    label,
                    colorLine: lineStyle.stroke,
                    range: {
                        rangeColor: lineStyle.fill || 'none',
                    },
                },
            });
            return () => legendDispatch({
                type: 'REMOVE_LEGEND_LABEL',
                payload: { id },
            });
        }
    }, [label, legendDispatch, lineStyle.fill, lineStyle.stroke, id, hidden]);
    if (hidden)
        return null;
    const lineProps = {
        id,
        data,
        xAxis,
        yAxis,
        lineStyle,
        transform: `translate(${xShift},${yShift})`,
    };
    return isVisible ? (0, jsx_runtime_1.jsx)(RangeSeriesRender, { ...lineProps }) : null;
}
exports.RangeSeries = (0, react_1.memo)(RangeSeriesInner);
function RangeSeriesRender({ data, xAxis, yAxis, lineStyle, transform, }) {
    // Get scales from context
    const { axisContext } = (0, plotContext_1.usePlotContext)();
    const [xScale, yScale] = (0, utils_1.validateAxis)(axisContext, xAxis, yAxis);
    // calculates the path to display
    const path = (0, react_1.useMemo)(() => {
        if (xScale === undefined || yScale === undefined) {
            return null;
        }
        // Calculate area from D3
        const areaGenerator = (0, d3_shape_1.area)()
            .x((d) => xScale(d.x))
            .y0((d) => yScale(d.y1))
            .y1((d) => yScale(d.y2));
        return areaGenerator(data);
    }, [data, xScale, yScale]);
    if (!path)
        return null;
    // default style
    const style = {
        strokeWidth: 2,
        ...lineStyle,
    };
    return (0, jsx_runtime_1.jsx)("path", { transform: transform, style: style, d: path, fill: "none" });
}
//# sourceMappingURL=RangeSeries.js.map