"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LegendProvider = void 0;
exports.useLegend = useLegend;
const jsx_runtime_1 = require("react/jsx-runtime");
const immer_1 = require("immer");
const react_1 = require("react");
const context = (0, react_1.createContext)(null);
function useLegend() {
    const ctx = (0, react_1.useContext)(context);
    if (!ctx) {
        throw new Error('context was not initialized');
    }
    return ctx;
}
const legendReducer = (0, immer_1.produce)((draft, action) => {
    switch (action.type) {
        case 'ADD_LEGEND_LABEL': {
            const { shape, ...newLegend } = action.payload;
            const index = draft.labels.findIndex(({ id }) => newLegend.id === id);
            if (index < 0) {
                draft.labels.push({ ...newLegend, shape, isVisible: true });
            }
            else {
                //isVisible should only updated in TOGGLE_VISIBILITY
                const isVisible = draft.labels[index].isVisible;
                draft.labels[index] = { ...newLegend, isVisible, shape };
            }
            return;
        }
        case 'REMOVE_LEGEND_LABEL': {
            const { id } = action.payload;
            const index = draft.labels.findIndex((val) => val.id === id);
            if (index !== -1) {
                draft.labels.splice(index, 1);
            }
            return;
        }
        case 'TOGGLE_VISIBILITY': {
            const { id } = action.payload;
            const index = draft.labels.findIndex((val) => val.id === id);
            if (index !== -1) {
                draft.labels[index].isVisible = !draft.labels[index].isVisible;
            }
            return;
        }
        default:
            throw new Error('unreachable');
    }
});
const initialLegendState = {
    labels: [],
};
const LegendProvider = (props) => {
    const [legendState, legendDispatch] = (0, react_1.useReducer)(legendReducer, initialLegendState);
    const ctx = (0, react_1.useMemo)(() => [legendState, legendDispatch], [legendState, legendDispatch]);
    return (0, jsx_runtime_1.jsx)(context.Provider, { value: ctx, children: props.children });
};
exports.LegendProvider = LegendProvider;
//# sourceMappingURL=legendContext.js.map