"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlotOverrides = usePlotOverrides;
exports.usePlotControls = usePlotControls;
exports.usePlotEvents = usePlotEvents;
exports.usePlotEventsPlotContext = usePlotEventsPlotContext;
exports.PlotController = PlotController;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const nestableContext_1 = require("./nestableContext");
const usePlotEvents_1 = require("./usePlotEvents");
const usePlotOverrides_1 = require("./usePlotOverrides");
const plotOverridesContext = (0, nestableContext_1.createNestableContext)(usePlotOverrides_1.initialPlotOverridesState);
function usePlotOverrides(options) {
    return plotOverridesContext.useNestedContext(options?.controllerId);
}
const plotControlsContext = (0, nestableContext_1.createNestableContext)(null);
function usePlotControls(options) {
    const id = options?.controllerId;
    const plotControls = plotControlsContext.useNestedContext(id);
    if (!plotControls) {
        throw new Error(`usePlotControls must be called in a child of PlotController (id=${String(id)})`);
    }
    return plotControls;
}
const plotEventsUserContext = (0, nestableContext_1.createNestableContext)(null);
function usePlotEvents(handlers, options = {}) {
    const { controllerId: id, disabled = false } = options;
    const userContext = plotEventsUserContext.useNestedContext(id);
    if (!disabled && !userContext) {
        throw new Error(`usePlotEvents must be called in a child of PlotController (id=${String(id)})`);
    }
    const ref = (0, react_1.useRef)(handlers);
    (0, react_1.useEffect)(() => {
        if (!disabled) {
            ref.current = handlers;
        }
    }, [disabled, handlers]);
    (0, react_1.useEffect)(() => {
        if (!disabled && userContext) {
            userContext.registerHandlers(ref);
            return () => userContext.unregisterHandlers(ref);
        }
    }, [disabled, userContext]);
}
const plotEventsPlotContext = (0, nestableContext_1.createNestableContext)(null);
function usePlotEventsPlotContext(options) {
    return plotEventsPlotContext.useNestedContext(options?.controllerId);
}
function PlotController(props) {
    const { id, children } = props;
    const { userActions, plotActions } = (0, usePlotEvents_1.usePlotEventsState)();
    const { overrides, controls } = (0, usePlotOverrides_1.usePlotOverridesState)();
    return ((0, jsx_runtime_1.jsx)(plotOverridesContext.NestedContextProvider, { id: id, value: overrides, children: (0, jsx_runtime_1.jsx)(plotControlsContext.NestedContextProvider, { id: id, value: controls, children: (0, jsx_runtime_1.jsx)(plotEventsUserContext.NestedContextProvider, { id: id, value: userActions, children: (0, jsx_runtime_1.jsx)(plotEventsPlotContext.NestedContextProvider, { id: id, value: plotActions, children: children }) }) }) }));
}
//# sourceMappingURL=plotControllerContext.js.map