"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlotEventsState = usePlotEventsState;
const react_1 = require("react");
function usePlotEventsState() {
    const plotEvents = (0, react_1.useRef)({
        currentPlot: null,
        plots: new Set(),
        handlers: new Set(),
    });
    const userActions = (0, react_1.useMemo)(() => ({
        registerHandlers(handlersRef) {
            plotEvents.current.handlers.add(handlersRef);
        },
        unregisterHandlers(handlersRef) {
            plotEvents.current.handlers.delete(handlersRef);
        },
    }), []);
    const plotActions = (0, react_1.useMemo)(() => {
        return {
            registerPlot(plotId) {
                plotEvents.current.plots.add(plotId);
            },
            unregisterPlot(plotId) {
                plotEvents.current.plots.delete(plotId);
            },
            handleEvent(plotId, eventName, eventData) {
                if (!plotEvents.current.plots.has(plotId)) {
                    return;
                }
                if (eventName === 'onPointerDown') {
                    plotEvents.current.currentPlot = plotId;
                }
                if (eventName === 'onPointerUp') {
                    plotEvents.current.currentPlot = null;
                }
                if (plotEvents.current.currentPlot !== null &&
                    plotEvents.current.currentPlot !== plotId) {
                    // Ignore events on other plots.
                    return;
                }
                for (const handler of plotEvents.current.handlers) {
                    if (handler.current?.[eventName]) {
                        // @ts-expect-error eventData is guaranteed to be compatible with eventName.
                        handler.current[eventName](eventData);
                    }
                }
            },
        };
    }, []);
    return { userActions, plotActions };
}
//# sourceMappingURL=usePlotEvents.js.map