"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStartMoveEnd = useStartMoveEnd;
const react_1 = require("react");
const plotControllerContext_1 = require("../contexts/plotController/plotControllerContext");
function useStartMoveEnd(options) {
    const ref = (0, react_1.useRef)(options);
    (0, react_1.useEffect)(() => {
        ref.current = options;
    }, [options]);
    const [data, setData] = (0, react_1.useState)(null);
    (0, plotControllerContext_1.usePlotEvents)({
        onPointerDown(result) {
            if (result.event.button !== 0 || result.event.altKey)
                return;
            const { coordinates, clampedCoordinates } = result;
            const position = { coordinates, clampedCoordinates };
            setData({ start: position });
            ref.current?.onStart?.(result, position, position);
        },
        onPointerMove(result) {
            // TODO: boolean that says if pointer is currently down?
            if (!data || result.event.altKey)
                return;
            const { coordinates, clampedCoordinates } = result;
            const position = { coordinates, clampedCoordinates };
            setData((data) => {
                if (!data)
                    return null;
                return {
                    ...data,
                    end: position,
                };
            });
            ref.current?.onMove?.(result, data.start, position);
        },
        onPointerUp(result) {
            if (result.event.button !== 0 || !data || result.event.altKey)
                return;
            setData(null);
            if (data.end) {
                ref.current?.onEnd?.(result, data.start, data.end);
            }
        },
    }, options);
    return data;
}
//# sourceMappingURL=useStartMoveEnd.js.map